<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QtGui::App</name>
    <message>
        <location filename="../gui/quick/app.cpp" line="306"/>
        <source>Waiting for backend …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="402"/>
        <location filename="../gui/quick/app.cpp" line="411"/>
        <source>Unable to open &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="440"/>
        <source>Copied value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="444"/>
        <source>Unable to copy value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="453"/>
        <source>Unable to copy &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="299"/>
        <source>Backend is starting …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="285"/>
        <source>Checking for data to import …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="287"/>
        <source>Importing configuration …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="289"/>
        <source>Exporting configuration …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="304"/>
        <source>Not connected to backend.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="309"/>
        <source>Saving configuration …</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../gui/quick/app.cpp" line="311"/>
        <source>There are %n notification(s)/error(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../gui/quick/app.cpp" line="313"/>
        <source>There are %n Syncthing API error(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="428"/>
        <source>Scanning is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="472"/>
        <source>Unable to load ignore patterns: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="493"/>
        <source>Unable to save ignore patterns: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="861"/>
        <source>Unable to resolve URL &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1066"/>
        <source>Syncthing API error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1066"/>
        <source>%1 Syncthing API errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1051"/>
        <location filename="../gui/quick/app.cpp" line="1067"/>
        <source>most recent: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1050"/>
        <source>Syncthing error/notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1050"/>
        <source>%1 Syncthing errors/notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1076"/>
        <source>Syncthing device wants to connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1086"/>
        <source>Syncthing device wants to share folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1166"/>
        <source>Another config change is still pending.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1277"/>
        <source>Unable to minimize app.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1324"/>
        <source>Unable to create settings directory under &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1313"/>
        <source>Unable to open settings under &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="215"/>
        <source>Triggered override of &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="217"/>
        <source>Triggered revert of &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="291"/>
        <source>Checking locations to move home directory …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="293"/>
        <source>Moving home directory …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1343"/>
        <source>Unable to read settings: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1346"/>
        <source>Unable to restore settings: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1347"/>
        <source>JSON document contains no object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1378"/>
        <source>Unable to save settings: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1406"/>
        <source>Unable to load HTTPs certificate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1474"/>
        <source>This build of the app cannot launch Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1499"/>
        <source>Persistent logging disabled and logfile removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1501"/>
        <source>Unable to remove logfile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1509"/>
        <source>Another import/export still pending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1562"/>
        <source>The Syncthing home directory under &quot;%1&quot; is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1575"/>
        <source>No Syncthing configuration file found under &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1633"/>
        <location filename="../gui/quick/app.cpp" line="1878"/>
        <source>Unable to import settings: settings directory was not located.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1640"/>
        <source>Waiting for backend to terminate before importing settings …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1674"/>
        <source>Imported app config from &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1687"/>
        <source>Imported Syncthing config and database from &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1705"/>
        <source>Unable to find folders/devices in current Syncthing config.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1720"/>
        <source>Merging %1 folders and %2 devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1722"/>
        <source>Unable to import folders/devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1740"/>
        <source>Unable to import settings: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1767"/>
        <source>unable to create export directory under &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1770"/>
        <source>settings directory was not located.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1827"/>
        <source>Default directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1843"/>
        <source>External storage %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1852"/>
        <source>Current home directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1884"/>
        <source>Waiting for backend to terminate before moving home …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1904"/>
        <source>Home directory stays the same.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1915"/>
        <source>Cleaned up new home directory &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1921"/>
        <source>Copied data from previous home directory &quot;%1&quot; to new one.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1924"/>
        <source>Cleaned up previous home directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1927"/>
        <source>Configured &quot;%1&quot; as new/empty Syncthing home.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1929"/>
        <source>Configured &quot;%1&quot; as Syncthing home.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1933"/>
        <source>Unable to move home directory: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1728"/>
        <source>Nothing has been imported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1790"/>
        <source>Unable to export settings: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.cpp" line="1783"/>
        <source>Settings have been exported to &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/quick/app.h" line="155"/>
        <source>not available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DevView</name>
    <message>
        <location filename="../gui/devview.cpp" line="65"/>
        <source>Copy value</source>
        <translation>Zkopírovat hodnotu</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="71"/>
        <source>Copy name</source>
        <translation>Zkopírovat název</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="74"/>
        <source>Copy ID</source>
        <translation>Zkopírovat identifikátor</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="80"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="85"/>
        <source>Pause</source>
        <translation type="unfinished">Pozastavit</translation>
    </message>
</context>
<context>
    <name>QtGui::DirView</name>
    <message>
        <location filename="../gui/dirview.cpp" line="77"/>
        <source>Copy value</source>
        <translation>Zkopírovat hodnotu</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="83"/>
        <source>Copy label/ID</source>
        <translation>Zkopírovat jmenovku/identifikátor</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="86"/>
        <source>Copy path</source>
        <translation>Zkopírovat popis umístění</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="91"/>
        <source>Rescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="96"/>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="101"/>
        <source>Pause</source>
        <translation type="unfinished">Pozastavit</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="105"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="109"/>
        <source>Browse remote files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="111"/>
        <source>Show/edit ignore patterns</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DownloadView</name>
    <message>
        <location filename="../gui/downloadview.cpp" line="67"/>
        <source>Copy value</source>
        <translation>Zkopírovat hodnotu</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="72"/>
        <source>Copy label/ID</source>
        <translation>Zkopírovat jmenovku/identifikátor</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="76"/>
        <source>Open in file browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayIcon</name>
    <message>
        <location filename="../gui/trayicon.cpp" line="58"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="62"/>
        <source>Rescan all</source>
        <translation>Znovu vše proskenovat</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="70"/>
        <source>Show internal errors</source>
        <translation>Zobrazit vnitřní chyby</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="75"/>
        <source>Show notifications/errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="82"/>
        <source>About</source>
        <translation>O Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="87"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="222"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="242"/>
        <source>Launcher error</source>
        <translation>Chyba spouštěče</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="258"/>
        <source>Syncthing notification - click to dismiss</source>
        <translation>Oznámení ze Syncthing – kliknutím zahodíte</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="288"/>
        <source>Syncthing device wants to connect - click for web UI</source>
        <translation>Syncthing zařízení se chce připojit – klikněte pro webové rozhraní</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="305"/>
        <source>New Syncthing folder - click for web UI</source>
        <translation>Nový Syncthing adresář – klikněte pro webové rozhraní</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="183"/>
        <source>Disconnected from Syncthing</source>
        <translation>Odpojeno od Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="54"/>
        <source>Open Syncthing</source>
        <translation>Otevřít Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="66"/>
        <source>Log</source>
        <translation>Záznam událostí</translation>
    </message>
</context>
<context>
    <name>QtGui::TrayWidget</name>
    <message>
        <location filename="../gui/traywidget.ui" line="11"/>
        <source>Syncthing Tray</source>
        <translation>Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="104"/>
        <location filename="../gui/traywidget.cpp" line="351"/>
        <source>About</source>
        <translation>O Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="63"/>
        <location filename="../gui/traywidget.cpp" line="472"/>
        <source>Connect</source>
        <translation>Připojit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="77"/>
        <location filename="../gui/traywidget.cpp" line="906"/>
        <location filename="../gui/traywidget.cpp" line="948"/>
        <source>Start</source>
        <translation>Spustit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="118"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="132"/>
        <source>Open Syncthing</source>
        <translation>Otevřít Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="294"/>
        <source>In</source>
        <translation>Přích.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="301"/>
        <source>Incoming traffic</source>
        <translation>Příchozí provoz</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="233"/>
        <location filename="../gui/traywidget.ui" line="253"/>
        <location filename="../gui/traywidget.ui" line="304"/>
        <location filename="../gui/traywidget.ui" line="324"/>
        <source>unknown</source>
        <translation>neznámé</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="223"/>
        <source>Global</source>
        <translation>Globální</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="230"/>
        <source>Global overall statistics</source>
        <translation>Globální celkové statistiky</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="240"/>
        <source>Local</source>
        <translation>Místní</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="250"/>
        <source>Local overall statistics</source>
        <translation>Místní celkové statistiky</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="311"/>
        <source>Out</source>
        <translation>odchoz.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="321"/>
        <source>Outgoing traffic</source>
        <translation>Odchozí provoz</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="355"/>
        <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
        <translation>Kliknutím na &lt;i&gt;nové &lt;/i&gt; oznámení&lt;br&gt;
(pro &lt;i&gt;alle&lt;/i&gt; oznámení, nahlédněte do záznamu událostí)</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="362"/>
        <location filename="../gui/traywidget.cpp" line="161"/>
        <source>New notifications</source>
        <translation>Nová oznámení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="392"/>
        <source>Folders</source>
        <translation>Adresáře</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="425"/>
        <source>Devices</source>
        <translation>Zařízení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="491"/>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="458"/>
        <source>Recent changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="523"/>
        <source>Show</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="533"/>
        <source>Dismiss</source>
        <translation>Zahodit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="133"/>
        <source>View own device ID</source>
        <translation>Zobrazit identifikátor místního zařízení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="138"/>
        <source>Restart Syncthing</source>
        <translation>Restartovat Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="143"/>
        <source>Show Syncthing log</source>
        <translation>Zobrazit záznam událostí v Syncthing</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="148"/>
        <source>Rescan all folders</source>
        <translation>Znovu proskenovat všechny složky</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="155"/>
        <source>Connection</source>
        <translation>Spojení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="177"/>
        <source>Show internal errors</source>
        <translation>Zobrazit vnitřní chyby</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="192"/>
        <source>Quit Syncthing Tray</source>
        <translation>Ukončit Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="440"/>
        <source>Do you really want to restart Syncthing?</source>
        <translation>Opravdu chcete Syncthing restartovat?</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="467"/>
        <source>Connecting …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="468"/>
        <source>Establishing connection to Syncthing …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="473"/>
        <source>Not connected to Syncthing, click to connect</source>
        <translation>Nepřipojeno k Syncthing, klikněte pro připojení se</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="478"/>
        <source>Unable to establish connection to Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="487"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="488"/>
        <source>Syncthing is running, click to pause all devices</source>
        <translation>Syncthing je spuštěné, kliknutím pozastavíte veškerá zařízení</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="493"/>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="494"/>
        <source>At least one device is paused, click to resume</source>
        <translation>Přinejmenším jedno zařízení je pozastaveno, kliknutím pokračujte</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="618"/>
        <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
        <translation>Zadané nastavení spojení &lt;em&gt;%1&lt;/em&gt; není definováno a proto je ignorováno.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="690"/>
        <source>The folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>Adresář &lt;i&gt;%1&lt;/i&gt; neexistuje místně.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="701"/>
        <source>The containing folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>Obsažený adresář &lt;i&gt;%1&lt;/i&gt; neexistuje místně.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="761"/>
        <source>Open item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="766"/>
        <source>Copy path</source>
        <translation type="unfinished">Zkopírovat popis umístění</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="770"/>
        <source>Copy device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="773"/>
        <source>Copy folder ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="902"/>
        <location filename="../gui/traywidget.cpp" line="942"/>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="903"/>
        <source>Stop Syncthing instance launched via tray icon</source>
        <translation>Zastavit instanci Syncthing spuštěnou prostřednictvím ikony v oznamovací oblasti</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="907"/>
        <source>Start Syncthing with the built-in launcher configured in the settings</source>
        <translation>Spustit Syncthing s vestavěným spouštěčem nastaveným v nastaveních</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="98"/>
        <source>Unable to </source>
        <translation>Nedaří se </translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="133"/>
        <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
        <translation>Oznamovací oblast systémového panelu je (pro tuto chvíli) nedostupná. Je možné otevřít nabídku oznamovací oblasti jako běžné okno pomocí příznaku „--windowed“. Dále je možné spustit s volbou „--wait“ a čekat na to, až bude oznamovací oblast k dispozici (namísto zobrazení této zprávy).</translation>
    </message>
    <message>
        <source>You must configure how to connect to Syncthing when using Syncthing Tray the first time.</source>
        <translation type="vanished">Je třeba nastavit jako se připojit k Syncthing ze Syncthing Tray.</translation>
    </message>
    <message>
        <source>Note that the settings dialog allows importing URL, credentials and API-key from the local Syncthing configuration.</source>
        <translation type="vanished">Poznamenejme, že dialog nastavení umožňuje importovat URL adresu, přihlašovací údaje a klíč k API z místního nastavení Syncthing.</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="160"/>
        <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
        <translation>Knihovny Qt byly sestaveny bez podpory pro ikonu v oznamovací oblasti. Měli byste otevřít nabídku pro oznamovací oblast jako běžné okno pomocí příznaku -w.</translation>
    </message>
</context>
</TS>
